From a74b17a97ce63c98ce6333b1d4942ea238ae1a69 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Tue, 11 Mar 2025 11:05:41 +0900
Subject: [PATCH 1/9] update readme
---
README.md | 1 +
1 file changed, 1 insertion(+)
diff --git a/README.md b/README.md
index 6e60893..15940f2 100644
--- a/README.md
+++ b/README.md
@@ -98,6 +98,7 @@ https://github.com/user-attachments/assets/49bc12b2-abaf-45de-a21c-67aacd9bb872
## ✨ Auto clone and install
- you can use this command to automatically clone the installer and ran the script for you
+- NOTE: `curl` package is required before running this command
```bash
sh <(curl -L https://raw.githubusercontent.com/JaKooLit/Arch-Hyprland/main/auto-install.sh)
```
From 050fd2dcc49082f383b3d2eab76859d2785ded97 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Wed, 12 Mar 2025 19:45:02 +0900
Subject: [PATCH 2/9] updated ags.sh
---
install-scripts/ags.sh | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/install-scripts/ags.sh b/install-scripts/ags.sh
index d16fb4b..a0112b5 100755
--- a/install-scripts/ags.sh
+++ b/install-scripts/ags.sh
@@ -77,8 +77,8 @@ printf "\n%.0s" {1..1}
printf "${INFO} Kindly Standby...cloning and compiling ${SKY_BLUE}Aylur's GTK shell $ags_tag${RESET}...\n"
printf "\n%.0s" {1..1}
# Clone repository with the specified tag and capture git output into MLOG
-if git clone --recursive -b "$ags_tag" --depth=1 https://github.com/Aylur/ags.git; then
- cd ags || exit 1
+if git clone --depth=1 https://github.com/JaKooLit/ags_v1.9.0.git; then
+ cd ags_v1.9.0 || exit 1
npm install
meson setup build
if sudo meson install -C build 2>&1 | tee -a "$MLOG"; then
From 9b3df653a9989f53693dcf27574af4f195996506 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Wed, 12 Mar 2025 19:48:58 +0900
Subject: [PATCH 3/9] updated changelogs
---
CHANGELOGS.md | 1 +
1 file changed, 1 insertion(+)
diff --git a/CHANGELOGS.md b/CHANGELOGS.md
index d9dca88..99e1635 100644
--- a/CHANGELOGS.md
+++ b/CHANGELOGS.md
@@ -2,6 +2,7 @@
## 11 March 2025
- Added uninstall script
+- forked AGS v1 into JakooLit repo. This is just incase Aylur decide to take down v1
## 10 March 2025
- Dropped pyprland in favor of hyprland built in tool for a drop down like terminal and Desktop magnifier
From ffee7f7b9a2be21c81c21d257dd617226f15bb4f Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Wed, 12 Mar 2025 23:01:38 +0900
Subject: [PATCH 4/9] minor install.sh update
---
install.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/install.sh b/install.sh
index 775c3a8..9180f22 100755
--- a/install.sh
+++ b/install.sh
@@ -212,7 +212,7 @@ if check_services_running; then
# Display the active login manager(s) in the whiptail message box
whiptail --title "Active non-SDDM login manager(s) detected" \
- --msgbox "The following login manager(s) are active:\n\n$active_list\n\nIf you want to install SDDM and SDDM theme, stop and disable first the active services above first before running this script\n\nYour option to install SDDM and SDDM theme has now been removed\n\n😎 Ja " 22 80
+ --msgbox "The following login manager(s) are active:\n\n$active_list\n\nIf you want to install SDDM and SDDM theme, stop and disable first the active services above first before running this script\n\nYour option to install SDDM and SDDM theme has now been removed\n\n- Ja " 22 80
fi
# Check if NVIDIA GPU is detected
From 68201117095716fe94ada0b442025b421fd187d1 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Thu, 13 Mar 2025 00:24:16 +0900
Subject: [PATCH 5/9] updated install.sh re-active login managers
---
install.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/install.sh b/install.sh
index 9180f22..df4824e 100755
--- a/install.sh
+++ b/install.sh
@@ -212,7 +212,7 @@ if check_services_running; then
# Display the active login manager(s) in the whiptail message box
whiptail --title "Active non-SDDM login manager(s) detected" \
- --msgbox "The following login manager(s) are active:\n\n$active_list\n\nIf you want to install SDDM and SDDM theme, stop and disable first the active services above first before running this script\n\nYour option to install SDDM and SDDM theme has now been removed\n\n- Ja " 22 80
+ --msgbox "The following login manager(s) are active:\n\n$active_list\n\nIf you want to install SDDM and SDDM theme, stop and disable the active services above, reboot before running this script\n\nYour option to install SDDM and SDDM theme has now been removed\n\n- Ja " 23 80
fi
# Check if NVIDIA GPU is detected
From eedc504ecda20588bba1af07bb9d9486c052cfc4 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Thu, 13 Mar 2025 19:22:24 +0900
Subject: [PATCH 6/9] updated discord links
---
CONTRIBUTING.md | 2 +-
README.md | 6 +++---
2 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index cb85810..5dba8eb 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -67,4 +67,4 @@ Thank you for your interest in contributing to Community Standards! We welcome a
## Contact
-If you have any questions, feel free to contact via [GitHub Discussions](https://github.com/JaKooLit/Arch-Hyprland/discussions) or [Through Discord Server](https://discord.gg/V2SJ92vbEN)
+If you have any questions, feel free to contact via [GitHub Discussions](https://github.com/JaKooLit/Arch-Hyprland/discussions) or [Through Discord Server](https://discord.gg/kool-tech-world)
diff --git a/README.md b/README.md
index 5cafd50..0b9bee9 100644
--- a/README.md
+++ b/README.md
@@ -6,7 +6,7 @@
-  
+  
@@ -34,7 +34,7 @@
Wiki
Keybinds
FAQ
-
Discord
+
Discord
@@ -213,7 +213,7 @@ env = WLR_RENDERER_ALLOW_SOFTWARE,1
- [`SEE HERE`](https://github.com/JaKooLit/Hyprland-Dots/discussions/123#discussion-6035205)
#### 📒 Final Notes
-- join my discord channel [`Discord`](https://discord.com/invite/9JEgZsfhex)
+- join my discord channel [`Discord`](https://discord.com/invite/kool-tech-world)
- Feel free to copy, re-distribute, and use this script however you want. Would appreciate if you give me some loves by crediting my work :)
From ff2e5a02e35b712f8cd9c5cde81b68170db46fd0 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Thu, 13 Mar 2025 19:45:46 +0900
Subject: [PATCH 7/9] updated packages message if all essential packages are
installed
---
install-scripts/02-Final-Check.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/install-scripts/02-Final-Check.sh b/install-scripts/02-Final-Check.sh
index 5f818a2..ac38ee9 100755
--- a/install-scripts/02-Final-Check.sh
+++ b/install-scripts/02-Final-Check.sh
@@ -66,7 +66,7 @@ done
# Log missing packages
if [ ${#missing[@]} -eq 0 ] && [ ${#local_missing[@]} -eq 0 ]; then
- echo "${OK} GREAT! It seems All ${YELLOW}essential packages${RESET} are installed." | tee -a "$LOG"
+ echo "${OK} GREAT! All ${YELLOW}essential packages${RESET} have been successfully installed." | tee -a "$LOG"
else
if [ ${#missing[@]} -ne 0 ]; then
echo "${WARN} The following packages are not installed and will be logged:"
From a4164ca612ba71c7c9aaddb5b48d6aff319182dc Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Thu, 13 Mar 2025 20:24:08 +0900
Subject: [PATCH 8/9] disabled blank issue template
---
.github/ISSUE_TEMPLATE/config.yml | 1 +
1 file changed, 1 insertion(+)
create mode 100644 .github/ISSUE_TEMPLATE/config.yml
diff --git a/.github/ISSUE_TEMPLATE/config.yml b/.github/ISSUE_TEMPLATE/config.yml
new file mode 100644
index 0000000..ec4bb38
--- /dev/null
+++ b/.github/ISSUE_TEMPLATE/config.yml
@@ -0,0 +1 @@
+blank_issues_enabled: false
\ No newline at end of file
From 36e84ebc5323fc733acf6f9bc350aa04483e7e18 Mon Sep 17 00:00:00 2001
From: JaKooLit
Date: Thu, 13 Mar 2025 23:16:04 +0900
Subject: [PATCH 9/9] replaced folders//folder with directories/directory
---
assets/.zshrc | 2 +-
install-scripts/ags.sh | 4 ++--
install-scripts/gtk_themes.sh | 4 ++--
install-scripts/paru.sh | 4 ++--
install-scripts/yay.sh | 4 ++--
5 files changed, 9 insertions(+), 9 deletions(-)
diff --git a/assets/.zshrc b/assets/.zshrc
index c1d57d6..7eaef61 100644
--- a/assets/.zshrc
+++ b/assets/.zshrc
@@ -25,7 +25,7 @@ source $ZSH/oh-my-zsh.sh
# fastfetch. Will be disabled if above colorscript was chosen to install
fastfetch -c $HOME/.config/fastfetch/config-compact.jsonc
-# Set-up icons for files/folders in terminal using lsd
+# Set-up icons for files/directories in terminal using lsd
alias ls='lsd'
alias l='ls -l'
alias la='ls -a'
diff --git a/install-scripts/gtk_themes.sh b/install-scripts/gtk_themes.sh
index ecc0d0c..4f5a486 100755
--- a/install-scripts/gtk_themes.sh
+++ b/install-scripts/gtk_themes.sh
@@ -32,7 +32,7 @@ done
# Check if the directory exists and delete it if present
if [ -d "GTK-themes-icons" ]; then
- echo "$NOTE GTK themes and Icons folder exist..deleting..." 2>&1 | tee -a "$LOG"
+ echo "$NOTE GTK themes and Icons directory exist..deleting..." 2>&1 | tee -a "$LOG"
rm -rf "GTK-themes-icons" 2>&1 | tee -a "$LOG"
fi
@@ -42,7 +42,7 @@ if git clone --depth=1 https://github.com/JaKooLit/GTK-themes-icons.git ; then
chmod +x auto-extract.sh
./auto-extract.sh
cd ..
- echo "$OK Extracted GTK Themes & Icons to ~/.icons & ~/.themes folders" 2>&1 | tee -a "$LOG"
+ echo "$OK Extracted GTK Themes & Icons to ~/.icons & ~/.themes directories" 2>&1 | tee -a "$LOG"
else
echo "$ERROR Download failed for GTK themes and Icons.." 2>&1 | tee -a "$LOG"
fi
diff --git a/install-scripts/paru.sh b/install-scripts/paru.sh
index 14388ce..f4b9609 100755
--- a/install-scripts/paru.sh
+++ b/install-scripts/paru.sh
@@ -37,7 +37,7 @@ if [ -n "$ISAUR" ]; then
else
printf "\n%s - Installing ${SKY_BLUE}$pkg${RESET} from AUR\n" "${NOTE}"
-# Check if folder exists and remove it
+# Check if directory exists and remove it
if [ -d "$pkg" ]; then
rm -rf "$pkg"
fi
@@ -45,7 +45,7 @@ fi
cd $pkg || { printf "%s - Failed to enter $pkg directory\n" "${ERROR}"; exit 1; }
makepkg -si --noconfirm 2>&1 | tee -a "$LOG" || { printf "%s - Failed to install ${YELLOW}$pkg${RESET} from AUR\n" "${ERROR}"; exit 1; }
- # moving install logs in to Install-Logs folder
+ # moving install logs in to Install-Logs directory
mv install*.log ../Install-Logs/ || true
cd ..
fi
diff --git a/install-scripts/yay.sh b/install-scripts/yay.sh
index a08042d..6dc9346 100755
--- a/install-scripts/yay.sh
+++ b/install-scripts/yay.sh
@@ -37,7 +37,7 @@ if [ -n "$ISAUR" ]; then
else
printf "\n%s - Installing ${SKY_BLUE}$pkg${RESET} from AUR\n" "${NOTE}"
-# Check if folder exists and remove it
+# Check if directory exists and remove it
if [ -d "$pkg" ]; then
rm -rf "$pkg"
fi
@@ -45,7 +45,7 @@ fi
cd $pkg || { printf "%s - Failed to enter $pkg directory\n" "${ERROR}"; exit 1; }
makepkg -si --noconfirm 2>&1 | tee -a "$LOG" || { printf "%s - Failed to install ${YELLOW}$pkg${RESET} from AUR\n" "${ERROR}"; exit 1; }
- # moving install logs in to Install-Logs folder
+ # moving install logs in to Install-Logs directory
mv install*.log ../Install-Logs/ || true
cd ..
fi
diff --git a/install-scripts/ags.sh b/install-scripts/ags.sh
index a0112b5..48afaba 100755
--- a/install-scripts/ags.sh
+++ b/install-scripts/ags.sh
@@ -67,9 +67,9 @@ printf "\n%.0s" {1..1}
# ags v1
printf "${NOTE} Install and Compiling ${SKY_BLUE}Aylur's GTK shell $ags_tag${RESET}..\n"
# Check if folder exists and remove it
if [ -d "ags" ]; then
- printf "${NOTE} Removing existing ags folder...\n"
+ printf "${NOTE} Removing existing ags directory...\n"
rm -rf "ags"
fi
@@ -67,9 +67,9 @@ printf "\n%.0s" {1..1}
# ags v1
printf "${NOTE} Install and Compiling ${SKY_BLUE}Aylur's GTK shell $ags_tag${RESET}..\n"
-# Check if folder exists and remove it
+# Check if directory exists and remove it
if [ -d "ags" ]; then